@@ -1,6 +1,6 @@
 #encoding=utf8
 from collections import namedtuple
-User = namedtuple('User', ['uid', 'uname', 'systemuser','manageuser','manageuserid','companyid','type'])
+User = namedtuple('User', ['uid', 'uname', 'systemuser','manageuser','manageuserid','companyid','phone','type'])
 
 class BaseAuth(object):
     """docstring for ClassName"""
