@@ -4,7 +4,9 @@
 #################################
 from mwauth.base_auth import BaseAuth,User
 from flask import request,make_response,g,current_app,session
+from flask_babel import _
 from functools import wraps
+import inspect
 from .redis_session import RedisSessionInterface
 import hashlib
 class KongAuth(BaseAuth):
@@ -29,6 +31,7 @@ class KongAuth(BaseAuth):
                                   manageuser=current_app.config.get('LOGIN_USER_MANAGEUSER', False),
                                   manageuserid=current_app.config.get('LOGIN_USER_MANAGEUSER_ID'),
                                   companyid=current_app.config.get('LOGIN_USER_COMPANYID',''),
+                                  phone = current_app.config.get('LOGIN_USER_PHONE'),
                                   type=session.get('type', 'appuser')
                                   )
             g.jwt = session.sid
@@ -92,8 +95,9 @@ class KongAuth(BaseAuth):
                               manageuser=session.get('manageuser', False),
                               manageuserid=session.get('manageuserid'),
                               companyid=session.get('companyid',''),
-                              type=session.get('type','appuser')
-                              )
+                              type=session.get('type','appuser'),
+                              phone=session.get('phone','')
+                )
         g.user_name = session.get('uname')
         g.user_id = session.get('uid')
 
@@ -121,6 +125,7 @@ class KongAuth(BaseAuth):
             return response
         return _request_login
 
+
     def valid_sign(self,func):
         @wraps(func)
         def _request_sign(*args, **kw):
@@ -137,16 +142,43 @@ class KongAuth(BaseAuth):
                 sign_source_str = f'{request.data.decode()}{g.jwt}' \
                                   f'{request.headers.get("X-MW-Noncestr") or request.args.get("noncestr", "")}' \
                                   f'{request.headers.get("X-MW-Timestamp") or request.args.get("timestamp", "")}'
-                sign_md5 = hashlib.md5(sign_source_str.encode()).hexdigest()
-                if sign_md5 == sign:
+                sign_md5_jwt = hashlib.md5(sign_source_str.encode()).hexdigest()
+                if sign_md5_jwt == sign:
                     return func(*args, **kw)
             # 没有认证则返回400
-            response = make_response({ "error": f'sign error,sign:{sign},noncestr:{request.args.get("noncestr", "")},'
-                                                f'timestamp:{request.args.get("timestamp", "")}'},
+            response = make_response({ "error": f'sign error,web sign:{sign},'
+                                                f'srv sign_user {sign_md5},'
+                                                f'srv sign_jwt{sign_md5_jwt},'
+                                                f'noncestr:{request.headers.get("X-MW-Noncestr") or request.args.get("noncestr", "")},'
+                                                f'timestamp:{request.headers.get("X-MW-Timestamp") or request.args.get("timestamp", "")}'},
                                      400, {"content-type": "application/json;charset=utf8"})
             response.status_code = 400
             return response
         return _request_sign
 
+    def valid_phone_code(self,phone_code_arg_name:str):
+        '''
+        检查验证码，需要传入验证码的参数名称
+        :param phone_code_arg_name: 函数中电话验证码的参数名称
+        :return:
+        '''
+        def wrapper(func):
+            @wraps(func)
+            def valid_phone_code(*args, **kwargs):
+                # 根据phone_code的参数名称获取phone_code验证码
+                phone_code = inspect.signature(func).bind_partial(*args, **kwargs).arguments.get(phone_code_arg_name)
+                assert phone_code is not None, f'验证码的参数名称{phone_code_arg_name}在函数中不存在'
+                phone = g.current_user.phone
+                rds = current_app.session_interface.redis
+                valid_code, hits = rds.hmget(f'session:phone.valid.code:{phone}', ['valid_code', 'hits'])
+                if valid_code and valid_code.decode() == phone_code:
+                    rds.delete(f'session:phone.valid.code:{phone}')
+                    return func(*args, **kwargs)
+                rds.hincrby(f'session:phone.valid.code:{phone}', 'hits', -1)
+                if hits and int(hits.decode()) <= 0:
+                    rds.delete(f'session:phone.valid.code:{phone}')
+                return  make_response({ "error": _('The phone valid code is error,please retry enter.')},  400, {"content-type": "application/json;charset=utf8"})
+            return valid_phone_code
+        return wrapper
 
 
